@@ -22,9 +22,9 @@ LinearEdictFile::LinearEdictFile()
 /**
  * Get everything that looks remotely like a given search string
  */
-QVector<QString> LinearEdictFile::findMatches(const QString &searchString) const
+QList<QString> LinearEdictFile::findMatches(const QString &searchString) const
 {
-    QVector<QString> matches;
+    QList<QString> matches;
     for (const QString &it : m_edict) {
         if (it.contains(searchString)) {
             matches.append(it);
